@@ -7,6 +7,8 @@
 # ADES
 ades <- SOS(url = "http://sosades.brgm.fr/REST/sos",
 		method = SosSupportedConnectionMethods()[["GET"]])
+print(object.size(ades), units=c("Mb"))
+# 7.8 Mb, large capabilities file!
 
 ades.off <- sosOfferingIds(ades)
 
